pub struct InFileWrapper<FileKind, T> {
pub file_id: FileKind,
pub value: T,
}Expand description
InFile<T> stores a value of T inside a particular file/syntax tree.
Typical usages are:
InFile<SyntaxNode>– syntax node in a fileInFile<ast::FnDef>– ast node in a fileInFile<TextSize>– offset in a file
Fields
file_id: FileKindvalue: TImplementations
Sourceimpl InFileWrapper<HirFileId, FileAstId<Macro>>
impl InFileWrapper<HirFileId, FileAstId<Macro>>
Sourcepub fn decl_macro_expander<'db>(
self: AstId<Macro>,
db: &'db dyn SourceDatabase,
def_crate: Crate,
) -> &'db DeclarativeMacroExpander
pub fn decl_macro_expander<'db>( self: AstId<Macro>, db: &'db dyn SourceDatabase, def_crate: Crate, ) -> &'db DeclarativeMacroExpander
Fetches (and compiles) the expander of this decl macro.
Sourceimpl<N: AstNode> InFileWrapper<HirFileId, FileAstId<N>>
impl<N: AstNode> InFileWrapper<HirFileId, FileAstId<N>>
pub fn to_node(&self, db: &dyn SourceDatabase) -> N
pub fn to_range(&self, db: &dyn SourceDatabase) -> TextRange
pub fn to_in_file_node(&self, db: &dyn SourceDatabase) -> InFile<N>
pub fn to_ptr(&self, db: &dyn SourceDatabase) -> AstPtr<N>
pub fn erase(&self) -> ErasedAstId
pub fn upcast<M: AstIdNode>(self) -> AstId<M>where
N: Into<M>,
Sourceimpl InFileWrapper<HirFileId, ErasedFileAstId>
impl InFileWrapper<HirFileId, ErasedFileAstId>
Sourceimpl<FileKind, N: AstNode> InFileWrapper<FileKind, AstPtr<N>>
impl<FileKind, N: AstNode> InFileWrapper<FileKind, AstPtr<N>>
pub fn upcast<M: AstNode>(self) -> InFileWrapper<FileKind, AstPtr<M>>where
N: Into<M>,
Sourceimpl<FileKind, T> InFileWrapper<FileKind, T>
impl<FileKind, T> InFileWrapper<FileKind, T>
Sourceimpl<FileKind: Copy, T> InFileWrapper<FileKind, T>
impl<FileKind: Copy, T> InFileWrapper<FileKind, T>
pub fn with_value<U>(&self, value: U) -> InFileWrapper<FileKind, U>
pub fn as_ref(&self) -> InFileWrapper<FileKind, &T>
pub fn borrow<U>(&self) -> InFileWrapper<FileKind, &U>where
T: Borrow<U>,
Sourceimpl<FileKind: Copy, T: Clone> InFileWrapper<FileKind, &T>
impl<FileKind: Copy, T: Clone> InFileWrapper<FileKind, &T>
pub fn cloned(&self) -> InFileWrapper<FileKind, T>
Sourceimpl<FileKind, T> InFileWrapper<FileKind, Option<T>>
impl<FileKind, T> InFileWrapper<FileKind, Option<T>>
pub fn transpose(self) -> Option<InFileWrapper<FileKind, T>>
Sourceimpl<FileKind, L, R> InFileWrapper<FileKind, Either<L, R>>
impl<FileKind, L, R> InFileWrapper<FileKind, Either<L, R>>
pub fn transpose( self, ) -> Either<InFileWrapper<FileKind, L>, InFileWrapper<FileKind, R>>
Sourceimpl<FileId: FileIdToSyntax, T> InFileWrapper<FileId, T>
impl<FileId: FileIdToSyntax, T> InFileWrapper<FileId, T>
pub fn file_syntax(&self, db: &dyn SourceDatabase) -> SyntaxNode
Sourceimpl<FileId: FileIdToSyntax, N: AstNode> InFileWrapper<FileId, AstPtr<N>>
impl<FileId: FileIdToSyntax, N: AstNode> InFileWrapper<FileId, AstPtr<N>>
Sourceimpl<FileId: Copy, N: AstNode> InFileWrapper<FileId, N>
impl<FileId: Copy, N: AstNode> InFileWrapper<FileId, N>
pub fn syntax(&self) -> InFileWrapper<FileId, &SyntaxNode>
pub fn node_file_range(&self) -> FileRangeWrapper<FileId>
Sourceimpl<FileId: Copy, N: AstNode> InFileWrapper<FileId, &N>
impl<FileId: Copy, N: AstNode> InFileWrapper<FileId, &N>
pub fn syntax_ref(&self) -> InFileWrapper<FileId, &SyntaxNode>
Sourceimpl<FileId: Copy, SN: Borrow<SyntaxNode>> InFileWrapper<FileId, SN>
impl<FileId: Copy, SN: Borrow<SyntaxNode>> InFileWrapper<FileId, SN>
pub fn file_range(&self) -> FileRangeWrapper<FileId>
Sourceimpl<SN: Borrow<SyntaxNode>> InFileWrapper<HirFileId, SN>
impl<SN: Borrow<SyntaxNode>> InFileWrapper<HirFileId, SN>
pub fn parent_ancestors_with_macros( self, db: &dyn SourceDatabase, ) -> impl Iterator<Item = InFile<SyntaxNode>> + '_
pub fn ancestors_with_macros( self, db: &dyn SourceDatabase, ) -> impl Iterator<Item = InFile<SyntaxNode>> + '_
pub fn kind(&self) -> SyntaxKind
pub fn text_range(&self) -> TextRange
Sourcepub fn original_file_range_rooted(self, db: &dyn SourceDatabase) -> FileRange
pub fn original_file_range_rooted(self, db: &dyn SourceDatabase) -> FileRange
Falls back to the macro call range if the node cannot be mapped up fully.
For attributes and derives, this will point back to the attribute only.
For the entire item use InFile::original_file_range_full.
Sourcepub fn original_file_range_with_macro_call_input(
self,
db: &dyn SourceDatabase,
) -> FileRange
pub fn original_file_range_with_macro_call_input( self, db: &dyn SourceDatabase, ) -> FileRange
Falls back to the macro call range if the node cannot be mapped up fully.
pub fn original_syntax_node_rooted( self, db: &dyn SourceDatabase, ) -> Option<InRealFile<SyntaxNode>>
Sourceimpl InFileWrapper<HirFileId, &SyntaxNode<RustLanguage>>
impl InFileWrapper<HirFileId, &SyntaxNode<RustLanguage>>
Sourcepub fn original_file_range_opt(
self,
db: &dyn SourceDatabase,
) -> Option<(FileRange, SyntaxContext)>
pub fn original_file_range_opt( self, db: &dyn SourceDatabase, ) -> Option<(FileRange, SyntaxContext)>
Attempts to map the syntax node back up its macro calls.
Sourceimpl InFileWrapper<MacroCallId, SyntaxToken<RustLanguage>>
impl InFileWrapper<MacroCallId, SyntaxToken<RustLanguage>>
pub fn upmap_once( self, db: &dyn SourceDatabase, ) -> InFile<SmallVec<[TextRange; 1]>>
Sourceimpl InFileWrapper<HirFileId, SyntaxToken<RustLanguage>>
impl InFileWrapper<HirFileId, SyntaxToken<RustLanguage>>
Sourcepub fn original_file_range(self, db: &dyn SourceDatabase) -> FileRange
pub fn original_file_range(self, db: &dyn SourceDatabase) -> FileRange
Falls back to the macro call range if the node cannot be mapped up fully.
Sourcepub fn original_file_range_opt(
self,
db: &dyn SourceDatabase,
) -> Option<FileRange>
pub fn original_file_range_opt( self, db: &dyn SourceDatabase, ) -> Option<FileRange>
Attempts to map the syntax node back up its macro calls.
Sourceimpl InFileWrapper<MacroCallId, TextSize>
impl InFileWrapper<MacroCallId, TextSize>
pub fn original_file_range( self, db: &dyn SourceDatabase, ) -> (FileRange, SyntaxContext)
Sourceimpl InFileWrapper<HirFileId, TextRange>
impl InFileWrapper<HirFileId, TextRange>
pub fn original_node_file_range( self, db: &dyn SourceDatabase, ) -> (FileRange, SyntaxContext)
pub fn original_node_file_range_rooted( self, db: &dyn SourceDatabase, ) -> FileRange
pub fn original_node_file_range_with_macro_call_input( self, db: &dyn SourceDatabase, ) -> FileRange
pub fn original_node_file_range_opt( self, db: &dyn SourceDatabase, ) -> Option<(FileRange, SyntaxContext)>
pub fn original_node_file_range_rooted_opt( self, db: &dyn SourceDatabase, ) -> Option<FileRange>
Sourceimpl<N: AstNode> InFileWrapper<HirFileId, N>
impl<N: AstNode> InFileWrapper<HirFileId, N>
pub fn original_ast_node_rooted( self, db: &dyn SourceDatabase, ) -> Option<InRealFile<N>>
Sourceimpl<T> InFileWrapper<HirFileId, T>
impl<T> InFileWrapper<HirFileId, T>
pub fn into_real_file(self) -> Result<InRealFile<T>, InFile<T>>